<?php
/*
Plugin Name: Call-Em-All
Plugin URI: https://www.call-em-all.com
Description: Add Call-Em-All SMS Opt-in Widget to Wordpress Site
Version: 1.0
Author: Call-Em-All
Author URI: https://www.call-em-all.com
License: GNU GPL v2
*/

function callemall_menu() {
  add_options_page('Call-Em-All', 'Call-Em-All', 10, basename(__FILE__),
                   'callemall_settings_page');

  add_action( 'admin_print_scripts-' . $menu, 'jscolor_script' );
}

/**
 * Add a 'Settings' link below the plugin name on the plugins page
 */
function callemall_plugin_action_links($links, $file) {
  if (basename($file) == basename(__FILE__)) {
    $l = '<a href="options-general.php?page=Call-Em-All.php">Settings</a>';
    array_unshift($links, $l);
  }
  return $links;
}


function callemall_settings_page() {
  $updated = null;
  $error = null;

  if ($_POST) {
    $site_url = trim($_POST['site_url']);
    $widget_key = trim($_POST['widget_key']);
    $button_color = trim($_POST['button_color']);
    $text_color = trim($_POST['text_color']);
    $button_position = trim($_POST['button_position']);
    $keywords = trim($_POST['keywords']);
    $show_name = trim($_POST['show_name']);
    $show_custom_field = trim($_POST['show_custom_field']);
    $custom_field_name = trim($_POST['custom_field_name']);


    if (!$site_url) {
      $error = 'Please enter a "Site URL"';
    } else if (!$widget_key) {
      $error = 'Please enter a "Widget Key"';
    } else if (!$keywords) {
      $error = 'Please enter at least 1 Keyword';
  	} else if ($text_color != 'Black' && $text_color != 'White') {
 		$error = 'Please choose either Black or White for text color';
    } else if ($button_position != 'Left' && $button_position != 'Right') {
 		$error = 'Please choose either left or right for button position';
    }
    else {
      update_option('callemall_site', $site_url);
      update_option('callemall_widget_key', $widget_key);
      update_option('callemall_button_color', $button_color);
      update_option('callemall_text_color', $text_color);
      update_option('callemall_button_position', $button_position);
      update_option('callemall_keywords', $keywords);
      update_option('callemall_show_name', $show_name);
      update_option('callemall_show_custom_field', $show_custom_field);
      update_option('callemall_custom_field_name', $custom_field_name);
      $updated = 'Settings saved!';
    }
  } else {
    $widget_key = get_option('callemall_widget_key');
    $site_url = get_option('callemall_site');
    $button_color = get_option('callemall_button_color');
	$text_color = get_option('callemall_text_color');
	$button_position = get_option('callemall_button_position');
	$keywords = get_option('callemall_keywords');
	$show_name = get_option('callemall_show_name');
	$show_custom_field = get_option('callemall_show_custom_field');
	$custom_field_name = get_option('callemall_custom_field_name');

    if (!$site_url) {
      $site_url = get_site_url();
    }
  }
  add_action('admin_enqueue_scripts','jscolor_script');

  include 'callemall-settings-template.php';
}

function callemall_setup_options() {
  add_option('callemall_widget_key');
  add_option('callemall_site', get_site_url());
  add_option('callemall_button_color', '#000000');
  add_option('callemall_text_color', 'White');
  add_option('callemall_button_position', 'Left');
  add_option('callemall_keywords', '');
  add_option('callemall_show_name', 0);
  add_option('callemall_show_custom_field', 0);
  add_option('callemall_custom_field_name', 0);
}

function callemall_uninstall() {
  delete_option('callemall_widget_key');
  delete_option('callemall_site');
  delete_option('callemall_button_color');
  delete_option('callemall_text_color');
  delete_option('callemall_button_position');
  delete_option('callemall_keywords');
  delete_option('callemall_show_name');
  delete_option('callemall_show_custom_field');
  delete_option('callemall_custom_field_name');
}


function callemall_widget_js() {
	include 'callemall-widget.php';
}

function jscolor_script() {
    wp_enqueue_script( 'my_jscolor_script', plugin_dir_url( __FILE__ ) . '/jscolor/jscolor.js' );
}

// Attach stuff
add_action('admin_menu', 'callemall_menu');
add_action('wp_head', 'callemall_widget_js');
add_filter('plugin_action_links','callemall_plugin_action_links', 10, 2);
register_activation_hook(__FILE__,'callemall_setup_options');
register_uninstall_hook(__FILE__, $callback)
?>